# 为rhosocial ActiveRecord做贡献

感谢您考虑为rhosocial ActiveRecord做贡献！本节提供了希望帮助改进项目的贡献者的指南和信息。

## 目录

- [想法与功能请求](ideas_and_feature_requests.md)
- [开发流程](development_process.md)
- [Bug修复](bug_fixes.md)
- [文档贡献](documentation_contributions.md)
- [赞助支持](sponsorship.md)

## 概述

rhosocial ActiveRecord是一个欢迎所有人贡献的开源项目。无论您是修复bug、添加功能、改进文档还是提供财务支持，我们都非常感谢您的贡献。

有关如何贡献的详细信息，请参阅上面链接的特定部分。您还可以查看仓库根目录中的[CONTRIBUTING.md](https://github.com/rhosocial/python-activerecord/blob/main/CONTRIBUTING.md)文件，以获取快速参考。

## 入门

如果您是开源项目贡献的新手，我们建议从以下几点开始：

1. 熟悉代码库
2. 寻找标记为"good first issue"或"help wanted"的问题
3. 阅读我们的文档，了解项目的架构和设计原则

我们期待您的贡献，并随时为您提供帮助！